@@ -16,6 +16,7 @@ uint8_t* memoryBlockFetchNull(YR_MEMORY_BLOCK*);
 
 YR_MEMORY_BLOCK* memoryBlockIteratorFirst(YR_MEMORY_BLOCK_ITERATOR*);
 YR_MEMORY_BLOCK* memoryBlockIteratorNext(YR_MEMORY_BLOCK_ITERATOR*);
+uint64_t memoryBlockIteratorFilesize(YR_MEMORY_BLOCK_ITERATOR*);
 */
 import "C"
 import (
@@ -31,6 +32,11 @@ type MemoryBlockIterator interface {
 	Next() *MemoryBlock
 }
 
+type MemoryBlockIteratorWithFilesize interface {
+	MemoryBlockIterator
+	Filesize() uint64
+}
+
 type memoryBlockIteratorContainer struct {
 	MemoryBlockIterator
 	// MemoryBlock holds return values of the First and Next methods
@@ -59,11 +65,15 @@ func makeMemoryBlockIteratorContainer(mbi MemoryBlockIterator) (c *memoryBlockIt
 // The caller is responsible to remove cmbi.context from callbackData
 // pool.
 func makeCMemoryBlockIterator(c *memoryBlockIteratorContainer) (cmbi *C.YR_MEMORY_BLOCK_ITERATOR) {
-	return &C.YR_MEMORY_BLOCK_ITERATOR{
-		context: callbackData.Put(c),
-		first:   C.YR_MEMORY_BLOCK_ITERATOR_FUNC(C.memoryBlockIteratorFirst),
-		next:    C.YR_MEMORY_BLOCK_ITERATOR_FUNC(C.memoryBlockIteratorNext),
+	cmbi = &C.YR_MEMORY_BLOCK_ITERATOR{
+		context:   callbackData.Put(c),
+		first:     C.YR_MEMORY_BLOCK_ITERATOR_FUNC(C.memoryBlockIteratorFirst),
+		next:      C.YR_MEMORY_BLOCK_ITERATOR_FUNC(C.memoryBlockIteratorNext),
 	}
+	if _, implementsFilesize := c.MemoryBlockIterator.(MemoryBlockIteratorWithFilesize); implementsFilesize {
+		cmbi.file_size = C.YR_MEMORY_BLOCK_ITERATOR_SIZE_FUNC(C.memoryBlockIteratorFilesize)
+	}
+	return cmbi
 }
 
 func (c *memoryBlockIteratorContainer) realloc(size int) {
@@ -148,3 +158,9 @@ func memoryBlockIteratorNext(cmbi *C.YR_MEMORY_BLOCK_ITERATOR) *C.YR_MEMORY_BLOC
 	c.MemoryBlock = c.MemoryBlockIterator.Next()
 	return memoryBlockIteratorCommon(cmbi, c)
 }
+
+//export memoryBlockIteratorFilesize
+func memoryBlockIteratorFilesize(cmbi *C.YR_MEMORY_BLOCK_ITERATOR) C.uint64_t {
+	c := callbackData.Get(cmbi.context).(*memoryBlockIteratorContainer)
+	return C.uint64_t(c.MemoryBlockIterator.(MemoryBlockIteratorWithFilesize).Filesize())
+}
